@@ -1,6 +1,6 @@
 package Dancer::Plugin::Auth::Twitter;
 {
-  $Dancer::Plugin::Auth::Twitter::VERSION = '0.03';
+  $Dancer::Plugin::Auth::Twitter::VERSION = '0.04';
 }
 #ABSTRACT: Authenticate with Twitter
 
@@ -41,7 +41,7 @@ register 'auth_twitter_init' => sub {
     debug "new twitter with $consumer_key , $consumer_secret, $callback_url";
 
     $_twitter = Net::Twitter->new({ 
-        'traits'            => ['API::REST', 'OAuth'],
+        'traits'            => ['API::RESTv1_1', 'OAuth'],
         'consumer_key'      => $consumer_key, 
         'consumer_secret'   => $consumer_secret,
     });
@@ -126,7 +126,7 @@ get '/auth/twitter/callback' => sub {
     };
 
     if ($@ || !$twitter_user_hash) {
-        core("no twitter_user_hash or error: ".$@);
+        Dancer::Logger::core("no twitter_user_hash or error: ".$@);
         return redirect $callback_fail;
     }
 
@@ -153,7 +153,7 @@ Dancer::Plugin::Auth::Twitter - Authenticate with Twitter
 
 =head1 VERSION
 
-version 0.03
+version 0.04
 
 =head1 SYNOPSIS
 
